@@ -16,3 +16,11 @@ class NT(object):
     def __new__(cls, _nt_name="NT", **kwargs):
         nt = namedtupled.map(kwargs, _nt_name=_nt_name)
         return nt
+
+
+if __name__ == '__main__':
+    class SF(NT):
+
+        def __new__(cls, a='a', b='b'):
+
+            return super().__new__(cls, a=a, b=b)
\ No newline at end of file
