@@ -7,20 +7,18 @@
 # @Email        : yuanjie@xiaomi.com
 # @Software     : PyCharm
 # @Description  :
+
 import os
-import numpy as np
 import pretty_errors
 
 from .pipe import *
 from .logger import *
 from .timer import timer
 from .cprint import cprint
-from .hashtrick import murmurhash
 from .NT import NT
 
-get_module_path = lambda path, file=__file__: \
-    os.path.normpath(os.path.join(os.getcwd(), os.path.dirname(file), path))
+if os.environ.get('disable_eager_execution'):
+    import tensorflow as tf
 
-
-def noramlize(x):
-    return x / np.linalg.norm(x, 2, axis=len(x.shape) > 1, keepdims=True)
+    tf.compat.v1.disable_eager_execution()
+    logger.info('关闭动态图')
