@@ -7,13 +7,13 @@
 # @Email        : yuanjie@xiaomi.com
 # @Software     : PyCharm
 # @Description  : 
-
+import os
 from loguru import logger
 from pathlib import Path
 
-
-def set_logger(log_cache=".", log_file_name="run.log"):
-    logger.add(Path(log_cache) / log_file_name,
+LOG_PATH = os.environ.get("LOG_PATH")
+if LOG_PATH:
+    logger.add(Path(LOG_PATH),
                rotation="100 MB",
                retention='1 days',
                enqueue=True,  # 异步
